# Generated by roxygen2: do not edit by hand

S3method(ff_draft,default)
S3method(ff_draft,espn_conn)
S3method(ff_draft,flea_conn)
S3method(ff_draft,mfl_conn)
S3method(ff_draft,sleeper_conn)
S3method(ff_draftpicks,default)
S3method(ff_draftpicks,espn_conn)
S3method(ff_draftpicks,flea_conn)
S3method(ff_draftpicks,mfl_conn)
S3method(ff_draftpicks,sleeper_conn)
S3method(ff_franchises,default)
S3method(ff_franchises,espn_conn)
S3method(ff_franchises,flea_conn)
S3method(ff_franchises,mfl_conn)
S3method(ff_franchises,sleeper_conn)
S3method(ff_league,default)
S3method(ff_league,espn_conn)
S3method(ff_league,flea_conn)
S3method(ff_league,mfl_conn)
S3method(ff_league,sleeper_conn)
S3method(ff_playerscores,default)
S3method(ff_playerscores,espn_conn)
S3method(ff_playerscores,flea_conn)
S3method(ff_playerscores,mfl_conn)
S3method(ff_playerscores,sleeper_conn)
S3method(ff_rosters,default)
S3method(ff_rosters,espn_conn)
S3method(ff_rosters,flea_conn)
S3method(ff_rosters,mfl_conn)
S3method(ff_rosters,sleeper_conn)
S3method(ff_schedule,default)
S3method(ff_schedule,espn_conn)
S3method(ff_schedule,flea_conn)
S3method(ff_schedule,mfl_conn)
S3method(ff_schedule,sleeper_conn)
S3method(ff_scoring,default)
S3method(ff_scoring,espn_conn)
S3method(ff_scoring,flea_conn)
S3method(ff_scoring,mfl_conn)
S3method(ff_scoring,sleeper_conn)
S3method(ff_scoring,template_conn)
S3method(ff_scoringhistory,default)
S3method(ff_scoringhistory,espn_conn)
S3method(ff_scoringhistory,flea_conn)
S3method(ff_scoringhistory,mfl_conn)
S3method(ff_scoringhistory,sleeper_conn)
S3method(ff_scoringhistory,template_conn)
S3method(ff_standings,default)
S3method(ff_standings,espn_conn)
S3method(ff_standings,flea_conn)
S3method(ff_standings,mfl_conn)
S3method(ff_standings,sleeper_conn)
S3method(ff_starter_positions,default)
S3method(ff_starter_positions,espn_conn)
S3method(ff_starter_positions,flea_conn)
S3method(ff_starter_positions,mfl_conn)
S3method(ff_starter_positions,sleeper_conn)
S3method(ff_starter_positions,template_conn)
S3method(ff_starters,default)
S3method(ff_starters,espn_conn)
S3method(ff_starters,flea_conn)
S3method(ff_starters,mfl_conn)
S3method(ff_starters,sleeper_conn)
S3method(ff_transactions,default)
S3method(ff_transactions,espn_conn)
S3method(ff_transactions,flea_conn)
S3method(ff_transactions,mfl_conn)
S3method(ff_transactions,sleeper_conn)
S3method(ff_userleagues,default)
S3method(ff_userleagues,espn_conn)
S3method(ff_userleagues,flea_conn)
S3method(ff_userleagues,mfl_conn)
S3method(ff_userleagues,sleeper_conn)
S3method(print,espn_api)
S3method(print,espn_conn)
S3method(print,flea_conn)
S3method(print,fleaflicker_api)
S3method(print,mfl_api)
S3method(print,mfl_conn)
S3method(print,sleeper_api)
S3method(print,sleeper_conn)
S3method(print,template_conn)
export("%>%")
export(.ff_clear_cache)
export(dp_clean_html)
export(dp_clean_names)
export(dp_cleannames)
export(dp_playerids)
export(dp_values)
export(espn_connect)
export(espn_getendpoint)
export(espn_getendpoint_raw)
export(espn_players)
export(espn_potentialpoints)
export(ff_connect)
export(ff_draft)
export(ff_draftpicks)
export(ff_franchises)
export(ff_league)
export(ff_playerscores)
export(ff_rosters)
export(ff_schedule)
export(ff_scoring)
export(ff_scoringhistory)
export(ff_standings)
export(ff_starter_positions)
export(ff_starters)
export(ff_template)
export(ff_transactions)
export(ff_userleagues)
export(ffverse_sitrep)
export(fleaflicker_connect)
export(fleaflicker_getendpoint)
export(fleaflicker_players)
export(fleaflicker_userleagues)
export(mfl_connect)
export(mfl_getendpoint)
export(mfl_players)
export(nflfastr_rosters)
export(nflfastr_weekly)
export(sleeper_connect)
export(sleeper_getendpoint)
export(sleeper_players)
export(sleeper_userleagues)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(nflreadr,ffverse_sitrep)
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(rlang,`%||%`)
importFrom(utils,str)
