---
title: "Sleeper: Get Endpoint"
output: rmarkdown::html_vignette
author: Tan Ho
date: "`r Sys.Date()`"
vignette: >
  %\VignetteIndexEntry{Sleeper: Get Endpoint}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

options(dplyr.summarise.inform = FALSE,
        rmarkdown.html_vignette.check_title = FALSE)

eval <- TRUE

tryCatch(expr = {
  
  download.file("https://github.com/ffverse/ffscrapr-tests/archive/1.4.7.zip","f.zip")
  unzip('f.zip', exdir = ".")
  
  httptest::.mockPaths(new = "ffscrapr-tests-1.4.7")},
  warning = function(e) eval <<- FALSE,
  error = function(e) eval <<- FALSE)

httptest::use_mock_api()
```

## Creating custom Sleeper API calls

```{r setup, message = FALSE, eval = eval}
library(ffscrapr)
library(dplyr)
library(purrr)
library(glue)
```

The [Sleeper API is pretty extensive](https://docs.sleeper.com). If there is something you'd like to access that's beyond the current scope of ffscrapr, you can use the lower-level "`sleeper_getendpoint`" function to create a GET request and access the data, while still using the authentication and rate-limiting features I've already created. 

Here is an example of how you can call one of the endpoints - in this case, let's pull Sleeper's trending players data! 

We'll start by opening up this page, https://docs.sleeper.com/#trending-players, which is the documentation page for this particular endpoint. From here, we can see that Sleeper's documentation says the endpoint is: 

`https://api.sleeper.app/v1/players/<sport>/trending/<type>?lookback_hours=<hours>&limit=<int>`

On first glance, you can see that it takes two parameters within the endpoint call itself (`sport` and `type`) and we can further adjust the query with HTTP parameters `lookback_hours` and `limit`. The sleeper_getendpoint function already has the `https://api.sleeper.app/v1/` part encoded, so all we'll need to do is pass in the remaining part of the URL as the endpoint, and pass the HTTP parameters in as arguments to the function (these are case sensitive!) 

We can use the `glue` package to parameterise this, although you can also use base R's paste function just as easily.

```{r eval = eval}

type <- "add"

query <- glue::glue('players/nfl/trending/{type}')

query

response_trending <- sleeper_getendpoint(query,lookback_hours = 48, limit = 10)

str(response_trending, max.level = 1)
```

Along with the parsed content, the function also returns the query and the response that was sent by the server. These are helpful for debugging, but we can turn the content into a dataframe with some careful application of the tidyverse. 

```{r eval = eval}

df_trending <- response_trending %>% 
  purrr::pluck("content") %>% 
  dplyr::bind_rows()

head(df_trending)
```

This isn't very helpful without knowing who these players are, so let's pull the players endpoint in as well - this one has a convenient function!

```{r eval = eval}

players <- sleeper_players() %>% 
  select(player_id, player_name, pos, team, age)

trending <- df_trending %>% 
  left_join(players, by = "player_id")

trending
```

There - this means something to us now! As of this writing (2020-11-10), Kalen Ballage was the most added player. Haven't we been bitten by this before?

```{r include = FALSE, eval = eval}
httptest::stop_mocking()

unlink(c("ffscrapr-tests-1.4.7","f.zip"), recursive = TRUE, force = TRUE)
```

